"""sky130ph - Skywater photonics PDK for the 130nm fab foundry.

TODO Create LayerStack, component library, and activate it here.
"""

__version__ = "0.0.1"
__author__ = "SkandanC <s39chand@uwaterloo.ca>"
from typing import List

__all__: List[str] = []
